Coverage for markupmirror.markup: 100%

# Coverage for markupmirror.markup : 100%

## 6 statements 6 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 | # Add all markup.* submodules here for autodiscovery from markupmirror.markup.base import * from markupmirror.markup.html import * from markupmirror.markup.markdown_ import * from markupmirror.markup.plaintext import * from markupmirror.markup.restructuredtext import * from markupmirror.markup.textile_ import *